import { z } from "zod";
export var RateType;
(function (RateType) {
    RateType[RateType["VARIABLE"] = 0] = "VARIABLE";
    RateType[RateType["FIXED"] = 1] = "FIXED";
})(RateType || (RateType = {}));
export var Amortization;
(function (Amortization) {
    Amortization[Amortization["ANNUITET"] = 0] = "ANNUITET";
    Amortization[Amortization["SERIE"] = 1] = "SERIE";
    Amortization[Amortization["REVOLVING"] = 2] = "REVOLVING";
})(Amortization || (Amortization = {}));
export var AccountType;
(function (AccountType) {
    AccountType["LOAN"] = "LOAN";
    AccountType["LEASING"] = "LEASING";
    AccountType["DEPOSIT"] = "DEPOSIT";
    AccountType["FACOTRING"] = "FACOTRING";
})(AccountType || (AccountType = {}));
export var AccountSubType;
(function (AccountSubType) {
    AccountSubType["INSTALLMENT LOAN"] = "INSTALLMENT LOAN";
    AccountSubType["REVOLVING CREDIT"] = "REVOLVING CREDIT";
    AccountSubType["RECOURSE"] = "RECOURSE";
    AccountSubType["NON-RECOURSE"] = "NON-RECOURSE";
    AccountSubType["ADMIN"] = "ADMIN";
    AccountSubType["HYBRID"] = "HYBRID";
})(AccountSubType || (AccountSubType = {}));
const dateStr = z
    .string()
    .refine((v) => new Date(v).toString() !== "Invalid Date", {
    message: "Invalid date",
});
export const reserveAccountQuerySchema = z.object({
    sourceSystemCode: z.string(),
    sourceApplicationId: z.string(),
    accountTypeCode: z.nativeEnum(AccountType),
    accountSubtypeCode: z.nativeEnum(AccountSubType),
});
export const TransactionListQuerySchema = z.object({
    correlationId: z.string().optional(),
    countryIds: z.string(),
    businessAreaIds: z.string(),
    legalId: z.string(),
});
export const createAccountRequestSchema = z.object({
    newAccountApplication: z.object({
        account: z
            .object({
            sourceSystemCode: z.string(),
            sourceApplicationID: z.string(),
            //sourceProductID: z.string(),
            accountTypeCode: z.nativeEnum(AccountType),
            accountSubtypeCode: z.nativeEnum(AccountSubType),
            originationDate: dateStr,
            startDate: dateStr,
            contractTypeCode: z.string().optional(),
            limitAmount: z.number().optional(),
            limitExpiryDate: dateStr.optional(),
            dueDay: z.number().min(1).max(28),
            interestGroupCode: z.string(),
            baseInterestRate: z.number().optional(),
            nominalInterestRate: z.number(),
            netLoanAmount: z.number(),
            objectPrice: z.number(),
            equityAmount: z.number().optional(),
            vatRate: z.number().optional(),
            vatAmount: z.number().optional(),
            contractDocTitle: z.string().optional(),
            contractDocURL: z.string().optional(),
            requireDirectDebit: z.boolean().optional(),
            directDebitAccountNo: z.string().optional(),
            directDebitAmountLimit: z.number().optional(),
            initiateDirectDebit: z.boolean().optional(),
            iban: z.string().optional(),
            factoringInvoiceLimit: z.number().optional(),
            disbursementBankAccountNo: z.string().optional(),
        })
            .strict(),
        accountDimension: z
            .array(z
            .object({
            dimensionCode: z.string(),
            dimensionValue: z.string(),
            dimensionDescription: z.string(),
        })
            .strict())
            .optional(),
        product: z
            .object({
            sourceProductID: z.string(),
            //productName: z.string(),
        })
            .strict(),
        paymentSeries: z
            .array(z
            .object({
            legNo: z.number(),
            termLength: z.number(),
            termCount: z.number(),
            minAmountTermCount: z.number().optional(),
            minAmountTermCountMax: z.number().optional(),
            rateType: z.nativeEnum(RateType),
            termDue: z.number().optional(),
            amortization: z.nativeEnum(Amortization),
            interestRate: z.number(),
            startBalance: z.number(),
            endBalance: z.number(),
            termFee: z.number(),
            netTermAmount: z.number().optional(),
            grossTermAmount: z.number().optional(),
        })
            .strict())
            .min(1),
        contact: z
            .array(z
            .object({
            //sourceSystemCode: z.string(),
            sourceContactID: z.string(),
            contactRoleCode: z.enum([
                "SIGNER",
                "COSIGNER",
                "GUARANTOR",
                "VENDOR",
                "BROKER",
                "SALESPERSON",
                "INTERNALUNDERWRITER",
                "INTERNALSALESPERSON",
                "REPURCHASER",
                "SUPPLIER",
                "INSURANCE",
                "CONTACTPERSON",
                "UBO",
                "POA",
                "OTHER",
            ]),
            otherRole: z.string().optional(),
            accountShare: z.number().optional(),
            organizationNo: z.string().optional(),
            socialSecurityNo: z.string(),
            dateOfBirthOrReg: dateStr.optional(),
            sectorCode: z.string().optional(),
            economicActivityCode: z.string().optional(),
            legalEntityTypeCode: z.string().optional(),
            companyName: z.string().optional(),
            firstName: z.string(),
            middleName: z.string(),
            surname: z.string(),
            salutationCode: z.string().optional(),
            jobTitle: z.string().optional(),
            eMail: z.string(),
            invoiceEMail: z.string().optional(),
            reminderEMail: z.string().optional(),
            phoneNo: z.string().optional(),
            mobilePhoneNo: z.string(),
            nationalityCode: z.enum(["NO"]),
            address: z.string(),
            address2: z.string().optional(),
            streetType: z.string().optional(),
            postCode: z.string(),
            city: z.string(),
            region: z.string().optional(),
            countryCode: z.enum(["NO"]),
            languageCode: z.enum(["NOR"]),
            guarantorType: z.string().optional(),
            guarantorAmount: z.number().optional(),
            guarantorExpiryDate: dateStr.optional(),
            bankAccountNo: z.string().optional(),
            bankAccountOwnershipVerified: z.boolean().optional(),
            bankAccountOwnershipVerificationComment: z.string().optional(),
            pep: z.enum(["NO PEP", "PEP", "PEP Relative", "PEP Associate"]),
            riskLevelAML: z.number(),
            citizenshipCode: z.array(z.enum(["NO", "SE", "DK", "FI"])),
            taxIdentification: z
                .array(z.object({
                countryCode: z.string(),
                taxIdNumber: z.string(),
            }))
                .optional(),
            kycAnswer: z
                .array(z.object({
                questionID: z.string(),
                answer: z.string(),
                timestamp: z.string(),
            }))
                .optional(),
            dateOfLastKYC: dateStr.optional(),
        })
            .strict())
            .min(1),
        disbursement: z.array(z
            .object({
            sourceDisbursementID: z.string(),
            recipientType: z.enum(["CUSTOMER", "VENDOR", "INTERNALACCOUNT"]),
            //sourceContactID: z.string(),
            coreAccountNo: z.string().optional(),
            bankAccountNo: z.string(),
            paymentDate: dateStr,
            currency: z.string().optional(),
            amount: z.number(),
            //externalDocNo: z.string(),
            //paymentReference: z.string().optional(), //KID
            //paymentText: z.string(), //Fritekst
        })
            .strict()),
        // commission: z
        //   .array(
        //     z.object({
        //       sourceCommissionID: z.string(),
        //       commissionTypeCode: z.string(),
        //       commissionCode: z.string(),
        //       commissionRecipient: z.string(),
        //       commissionRecipientID: z.string(),
        //       commissionBaseType: z.string(),
        //       commissionAmount: z.number(),
        //       commissionValueType: z.string(),
        //       commissionValue: z.number(),
        //       commissionMargin: z.number(),
        //       commissionTermCount: z.number(),
        //     })
        //   )
        //   .optional(),
        fee: z.array(z
            .object({
            sourceFeeID: z.string().optional(),
            feeTypeCode: z.string().optional(),
            feeCode: z.enum(["TINGLYSING"]),
            feeAmountType: z.string().optional(),
            feeAmount: z.number(),
            feeValueType: z.string().optional(),
            feeValue: z.number().optional(),
            includeInInterestCalc: z.boolean(),
            feeIsFinanced: z.boolean(), //Når dette inngår i hovedstol
        })
            .strict()),
        brand: z.array(z
            .object({
            brandCode: z.string(),
            brandOrgNo: z.string().optional(),
            brandCompany: z.string().optional(),
        })
            .strict()),
        additionalProduct: z
            .array(z
            .object({
            productCode: z.string(),
            startDate: dateStr,
            endDate: dateStr,
            priceCalcType: z.string(),
            priceCalcValue: z.number(),
            consentDate: dateStr,
            freeTerms: z.number(),
            minimumPrice: z.number(),
        })
            .strict())
            .optional(),
        object: z.array(z
            .object({
            coreObjectNo: z.string(),
            sourceObjectID: z.string(),
            objectIdNumber: z.string().optional(),
            objectDescription: z.string(),
            objectDescriptionLong: z.string().optional(),
            objectMake: z.string().optional(),
            objectModel: z.string().optional(),
            objectEngine: z.string().optional(),
            objectYear: z.number().optional(),
            objectIsFinanced: z.boolean().optional(),
            installationInfo: z.string().optional(),
            insuranceName: z.string().optional(),
            insuranceOrgNo: z.string().optional(),
            insurancePolicyNo: z.string().optional(),
            insuranceInfo: z.string().optional(),
            objectGroupCode: z.string().optional(),
            objectSubgroupCode: z.string().optional(),
            objectConditionCode: z.number().optional(),
            depotValue: z.number(),
            depotDate: z.string(),
            depotPropertyCommonDebt: z.number(),
            depotPropertyCommonDebtDate: z.string(),
            depotPropertyAreaScore: z.number(),
            depotPropertyMunicipalityScore: z.number(),
            depotPropertyAreaVactionScore: z.number(),
            objectPropertyAddress: z.string(),
            objectPropertyZip: z.string(),
            objectPropertyLandNo: z.string(),
            objectPropertyUnitNo: z.string(),
            objectPropertyMunicipalNo: z.string(),
            objectPropertyLeaseNo: z.string(),
            objectPropertySectionNo: z.string(),
            objectPropertyOrganizationNo: z.string(),
            objectPropertyShareNo: z.string(),
        })
            .strict()),
        security: z
            .array(z
            .object({
            sourceSecurityID: z.string().optional(),
            sourceObjectID: z.string(),
            //sourceContactID: z.string(), //SSN
            //securityTypeCode: z.string(), //Må definere koder
            securityFaceValue: z.number(),
            securityExpirationDate: dateStr,
            // securityOrderOfPriority: z.number(),
            // securityOfficialRegistrationDocNo: z.string(), //Dagboknummer
            // securityPriorityAmount: z.number(),
            // securityPriorityEqualToAmount: z.number(),
            // securityDescription: z.string(),
            // securityRegistrationDate: dateStr,
            registrationDocumentNo: z.number(),
            registrationDocumentYear: z.number(),
            registrationOfficeNo: z.number(),
            registrationRightNo: z.number(),
        })
            .strict())
            .optional(),
        accountDocument: z.array(z
            .object({
            sentForReservation: z.boolean().optional(),
            sourceDocumentGUID: z.string(),
            documentType: z.string(),
            documentTitle: z.string(),
            documentURL: z.string(),
            documentContent: z.string().optional(),
            documentContentFileType: z.string().optional(), //PDF....
        })
            .strict()),
        text: z.array(z.string()).optional(),
    }),
});
